{% load wagtailcore_tags wagtailimages_tags core_tags i18n %}
{% load_descendant_articles_for_section section featured_in_homepage=True as featured_articles %}
{% if featured_articles %}
<div class="section-listing section-listing__column section-listing__column{{section.get_effective_extra_style_hints}}">
  <h1 class="heading subsection-listing__column-title">
    <a href="{% pageurl section %}" class="subsection-listing__column-link">{{section.title}}</a>
  </h1>
  <ul class="promoted-article-list promoted-article-list-column">
  {% for article in featured_articles %}
  <li class="promoted-article-list__item {% if forloop.first %}promoted-article-list__item--hero-column{% endif %} promoted-article-list__item-column">
    {% if article.get_effective_image %}
    <a href="{% pageurl article %}" class="promoted-article-list__anchor promoted-article-list__anchor-column">
      {% if forloop.first %}
        {% include "patterns/basics/images/article-image.html" with curve="semi-round" %}
      {% else %}
        {% include "patterns/basics/images/article-thumbnail_medium.html" with curve="none" %}
      {% endif %}
    </a>
    {% endif %}
    <a href="{% pageurl article %}" class="promoted-article-list__anchor promoted-article-list__anchor-column">
      <h3 class="heading promoted-article-list__column-heading">
        {{article.title}}
      </h3>
    </a>
    <p class="promoted-article-list__desc promoted-article-list__desc--column">{{article.subtitle}}</p>
  </li>
  {% endfor %}
  </ul>
</div>
{% endif %}
{% include "patterns/basics/pagination/pagination-pageof.html" %}
